@@ -4,14 +4,23 @@ use 5.010;
 use strict;
 use warnings FATAL => 'all';
 
+# turn of experimental warnings
+no if $] > 5.017010, warnings => 'experimental::smartmatch';
+
 use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
-our $VERSION = '0.24_04';
+our $VERSION = '0.25_02';
+
+BEGIN {
+	use Term::ReadLine;
+	use Term::ReadKey;
+	use Term::ReadLine::Perl;
+}
 
 use utf8;
-use IO::Socket::IP 0.18;
-use Carp 1.20 qw(carp croak);
+use IO::Socket::IP 0.21;
+use Carp 1.26 qw(carp croak);
 
 use constant {
 	BLANK => qq{ },
@@ -681,7 +690,7 @@ Debug::Client - debugger client side code for Padre, The Perl IDE.
 
 =head1 VERSION
 
-This document describes Debug::Client version: 0.24_04
+This document describes Debug::Client version: 0.25_02
 
 =head1 SYNOPSIS
 
